@@ -87,7 +87,7 @@ class Act():
 
     def get_uwsgi_port(self):
         """Get the uwsgi port using lsof.  Requires that lsof and fuser be suid root"""
-        self.uwsgi_ip = None; self.uwsgi_port = None
+        start_port =self.uwsgi_port
         timeout = 10
         nap = 1
         starttime = time.time()
@@ -95,11 +95,15 @@ class Act():
         while elapsed < timeout:
             try:
                 fullport = uwsgi_portsniffer.port_from_lsof(self.vassal_file)
-                self.uwsgi_ip, self.uwsgi_port = fullport.split(':')
-                break
+                new_ip, new_port = fullport.split(':')
+                if new_port <> start_port:
+                    self.uwsgi_ip = new_ip
+                    self.uwsgi_port = new_port
+                    break
             except:
-                time.sleep(nap)
-                elapsed = time.time() - starttime
+                pass
+            time.sleep(nap)
+            elapsed = time.time() - starttime
         return
 
 
